@@ -9,23 +9,16 @@
  *
  */
 
+/*
+ * In order to use any of the netcdf_XXX.h files, it is necessary
+ * to include netcdf.h followed by any netcdf_XXX.h files.
+ * Various things (like EXTERNL) are defined in netcdf.h
+ * to make them available for use by the netcdf_XXX.h files.
+*/
+
 #ifndef NETCDF_MEM_H
 #define NETCDF_MEM_H 1
 
-/* Declaration modifiers for DLL support (MSC et al) */
-#if defined(DLL_NETCDF) /* define when library is a DLL */
-#  if defined(DLL_EXPORT) /* define when building the library */
-#   define MSC_EXTRA __declspec(dllexport)
-#  else
-#   define MSC_EXTRA __declspec(dllimport)
-#  endif
-#  include <io.h>
-#else
-#define MSC_EXTRA  /**< Needed for DLL build. */
-#endif  /* defined(DLL_NETCDF) */
-
-#define EXTERNL MSC_EXTRA extern /**< Needed for DLL build. */
-
 typedef struct NC_memio {
     size_t size;
     void* memory;
@@ -37,12 +30,12 @@ typedef struct NC_memio {
 extern "C" {
 #endif
 
-/* Treate a memory block as a file; read-only */
+/* Treat a memory block as a file; read-only */
 EXTERNL int nc_open_mem(const char* path, int mode, size_t size, void* memory, int* ncidp);
 
 EXTERNL int nc_create_mem(const char* path, int mode, size_t initialsize, int* ncidp);
 
-/* Alternative to nc_open_mem with extended capabilites
+/* Alternative to nc_open_mem with extended capabilities
    See docs/inmemory.md
  */
 EXTERNL int nc_open_memio(const char* path, int mode, NC_memio* info, int* ncidp);
